from puglang import __version__

__author__ = "Johnny Starr"
__copyright__ = "(c) 2022 Johnny Starr"
__license__ = "MIT"


def run():
    print(f"Bark! - pug {__version__}")


if __name__ == "__main__":
    run()



class LexicalError(Exception):
    pass


class Lexer:
    def __init__(self):
        self.tokens = []
        self.source_code = ""

    def load(self, source_code):
        self.source_code = source_code

    def lex(self):
        if self.source_code == "":
            raise LexicalError("No source code for lexical scanning.")
        print("Lexing")



import pytest

from puglang.lang.lexer import Lexer, LexicalError


@pytest.fixture
def lexer():
    return Lexer()


def test_lexer_is_not_none(lexer):
    assert lexer is not None


def test_lexer_load_source_code(lexer):
    lexer.load("i=1")


def test_lexer_fails_without_load(lexer):
    with pytest.raises(LexicalError):
        lexer.lex()


def test_lexer_loads_and_lex(lexer):
    lexer.load("i=1")
    lexer.lex()
